<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://scoutech.com.br
 * @since      1.12
 *
 * @package    ScoutSportsBR
 * @subpackage ScoutSportsBR/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.12
 * @package    ScoutSportsBR
 * @subpackage ScoutSportsBR/includes
 * @author     Julian Romero <jromero@swim.com.br>
 */
class ScoutSportsBR {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      ScoutSportsBR_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * The default values
	 *
	 * @since    1.0.0
	 */
	public $default_values;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'scoutsportsbr';
		$this->version = '1.13';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_default_values();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Plugin_Name_Loader. Orchestrates the hooks of the plugin.
	 * - Plugin_Name_i18n. Defines internationalization functionality.
	 * - Plugin_Name_Admin. Defines all hooks for the admin area.
	 * - Plugin_Name_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-scoutsportsbr-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-scoutsportsbr-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-scoutsportsbr-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-scoutsportsbr-public.php';

		$this->loader = new ScoutSportsBR_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Plugin_Name_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new ScoutSportsBR_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new ScoutSportsBR_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		// Add menu item
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu' );

		// Add Settings link to the plugin
		$plugin_basename = plugin_basename( plugin_dir_path( __DIR__ ) . $this->plugin_name . '.php' );
		$this->loader->add_filter( 'plugin_action_links_' . $plugin_basename, $plugin_admin, 'add_action_links' );

		// Save/Update our plugin options
		$this->loader->add_action('admin_init', $plugin_admin, 'options_update');

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new ScoutSportsBR_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'init', $plugin_public, 'scoutsportsbr_register_shortcodes' );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Plugin_Name_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 * definir os valores padrões necessários para chamar a tabela
	 *
	 * @since     1.15
	 * @return    array      valores padroes.
	 */
	public function define_default_values() {

		$this->default_values=array(
			'exibir-artilharia-ranking' => '1',
			'exibir-artilharia-atleta' => '1',
			'exibir-artilharia-foto-atleta' => '1',
			'exibir-artilharia-equipe' => '1',
			'exibir-artilharia-foto-equipe' => '1',
			'exibir-artilharia-gols' => '1',
			'exibir-estatistica-total-jogos' => '1',
			'exibir-estatistica-total-gols' => '1',
			'exibir-estatistica-media-gols' => '1',
			'exibir-estatistica-total-assistencias' => '1',
			'exibir-estatistica-total-ca' => '1',
			'exibir-estatistica-total-cv' => '1',
			'exibir-estatistica-total-wo' => '1',
			'exibir-estatistica-total-derrotas' => '1',
			'exibir-estatistica-total-vitorias' => '1',
			'exibir-estatistica-total-empates' => '1',
			'exibir-estatistica-foto-jogador' => '1',
			'exibir-estatistica-logo-equipe' => '1',
			'exibir-estatistica-nome-jogador' => '1',
			'exibir-estatistica-nome-equipe' => '1',
			'exibir-ranking' => '1',
			'exibir-ranking-numero-jogos' => '1',
			'exibir-ranking-total' => '1',
			'exibir-ranking-nome-equipe' => '1',
			'exibir-ranking-foto-jogador' => '1',
			'exibir-ranking-logo-equipe' => '1',
			'exibir-ranking-nome-jogador' => '1',
			'exibir-categorias' => '0',
			'exibir-equipe' => '1',
			'exibir-sigla' => '1',
			'ocorrencia' => 'GOL',
			'ranking' => 'jogador',
			'limite' => '10',
			'jogo' => '',
			'sede' => '',
			'grupo' => '',
			'fase' => '',
			'equipe' => '',
			'reduzido' => '',
			'sem-titulo' => '1',
			'periodo' => '',
			'sem-ranking' => '',
			'categoria' => '',
			'id-campeonato' => '0',
			'modelo' => '',
			'css' => '1'
		);

		return $this->default_values;

	}

}
